package com.ruoyi.powerdistribution.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.powerdistribution.mapper.PdmStopRecordsMapper;
import com.ruoyi.powerdistribution.domain.PdmStopRecords;
import com.ruoyi.powerdistribution.service.IPdmStopRecordsService;

/**
 * 可靠性停电记录Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-18
 */
@Service
public class PdmStopRecordsServiceImpl implements IPdmStopRecordsService
{
    @Autowired
    private PdmStopRecordsMapper pdmStopRecordsMapper;

    /**
     * 查询可靠性停电记录
     *
     * @param id 可靠性停电记录主键
     * @return 可靠性停电记录
     */
    @Override
    public PdmStopRecords selectPdmStopRecordsById(Long id)
    {
        return pdmStopRecordsMapper.selectPdmStopRecordsById(id);
    }

    /**
     * 查询可靠性停电记录列表
     *
     * @param pdmStopRecords 可靠性停电记录
     * @return 可靠性停电记录
     */
    @Override
    public List<PdmStopRecords> selectPdmStopRecordsList(PdmStopRecords pdmStopRecords)
    {
        return pdmStopRecordsMapper.selectPdmStopRecordsList(pdmStopRecords);
    }

    /**
     * 新增可靠性停电记录
     *
     * @param pdmStopRecords 可靠性停电记录
     * @return 结果
     */
    @Override
    public int insertPdmStopRecords(PdmStopRecords pdmStopRecords)
    {
        pdmStopRecords.setCreateTime(DateUtils.getNowDate());
        return pdmStopRecordsMapper.insertPdmStopRecords(pdmStopRecords);
    }

    /**
     * 修改可靠性停电记录
     *
     * @param pdmStopRecords 可靠性停电记录
     * @return 结果
     */
    @Override
    public int updatePdmStopRecords(PdmStopRecords pdmStopRecords)
    {
        pdmStopRecords.setUpdateTime(DateUtils.getNowDate());
        return pdmStopRecordsMapper.updatePdmStopRecords(pdmStopRecords);
    }

    /**
     * 批量删除可靠性停电记录
     *
     * @param ids 需要删除的可靠性停电记录主键
     * @return 结果
     */
    @Override
    public int deletePdmStopRecordsByIds(Long[] ids)
    {
        return pdmStopRecordsMapper.deletePdmStopRecordsByIds(ids);
    }

    /**
     * 删除可靠性停电记录信息
     *
     * @param id 可靠性停电记录主键
     * @return 结果
     */
    @Override
    public int deletePdmStopRecordsById(Long id)
    {
        return pdmStopRecordsMapper.deletePdmStopRecordsById(id);
    }
}
